summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/orbsvcs/Notify/Notify_ProxyConsumer_T.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/orbsvcs/orbsvcs/Notify/Notify_ProxyConsumer_T.h')
-rw-r--r--TAO/orbsvcs/orbsvcs/Notify/Notify_ProxyConsumer_T.h55
1 files changed, 21 insertions, 34 deletions
diff --git a/TAO/orbsvcs/orbsvcs/Notify/Notify_ProxyConsumer_T.h b/TAO/orbsvcs/orbsvcs/Notify/Notify_ProxyConsumer_T.h
index 6cdafeaf614..c0eb08d0e84 100644
--- a/TAO/orbsvcs/orbsvcs/Notify/Notify_ProxyConsumer_T.h
+++ b/TAO/orbsvcs/orbsvcs/Notify/Notify_ProxyConsumer_T.h
@@ -18,14 +18,8 @@
#ifndef TAO_NOTIFY_PROXYCONSUMER_T_H
#define TAO_NOTIFY_PROXYCONSUMER_T_H
#include "ace/pre.h"
-#include "Notify_Proxy_T.h"
-
-#if !defined (ACE_LACKS_PRAGMA_ONCE)
-# pragma once
-#endif /* ACE_LACKS_PRAGMA_ONCE */
-
-#include "Notify_Listeners.h"
+#include "Notify_Proxy_T.h"
class TAO_Notify_SupplierAdmin_i;
#if defined(_MSC_VER)
@@ -36,7 +30,7 @@ class TAO_Notify_SupplierAdmin_i;
#endif /* _MSC_VER */
template <class SERVANT_TYPE>
-class TAO_Notify_Export TAO_Notify_ProxyConsumer : public TAO_Notify_Proxy<SERVANT_TYPE>, virtual public TAO_Notify_EventSource
+class TAO_Notify_Export TAO_Notify_ProxyConsumer : public TAO_Notify_Proxy<SERVANT_TYPE>
{
// = TITLE
// TAO_Notify_ProxyConsumer
@@ -46,26 +40,19 @@ class TAO_Notify_Export TAO_Notify_ProxyConsumer : public TAO_Notify_Proxy<SERVA
//
public:
- TAO_Notify_ProxyConsumer (TAO_Notify_SupplierAdmin_i* supplier_admin);
+ TAO_Notify_ProxyConsumer (TAO_Notify_SupplierAdmin_i* supplieradmin,
+ TAO_Notify_Resource_Manager* resource_manager);
// Constructor
virtual ~TAO_Notify_ProxyConsumer (void);
// Destructor
- void init (CosNotifyChannelAdmin::ProxyID myID, CORBA::Environment &ACE_TRY_ENV);
- // Init the Proxy.
-
- // = TAO_Notify_EventSource methods.
- virtual CORBA::Boolean evaluate_filter (TAO_Notify_Event &event, CORBA::Environment &ACE_TRY_ENV);
- // Evaluates true if this event is acceptable by the Source.
-
- TAO_Notify_Worker_Task* filter_eval_task (void);
- // The Worker task associated with the event listener for filter evaluation.
-
- virtual CosNotifyChannelAdmin::SupplierAdmin_ptr MyAdmin (CORBA::Environment &ACE_TRY_ENV)
- ACE_THROW_SPEC ((
- CORBA::SystemException
- ));
+ virtual CosNotifyChannelAdmin::SupplierAdmin_ptr MyAdmin (
+ CORBA::Environment &ACE_TRY_ENV
+ )
+ ACE_THROW_SPEC ((
+ CORBA::SystemException
+ ));
virtual CosNotification::EventTypeSeq * obtain_subscription_types (
CosNotifyChannelAdmin::ObtainInfoMode mode,
@@ -85,20 +72,20 @@ virtual void offer_change (
CosNotifyComm::InvalidEventType
));
-protected:
- // = Helper methods
- void on_connected (CORBA::Environment &ACE_TRY_ENV);
- // Derived classes should call this when their suppliers connect.
+ protected:
+// = Helper methods
+ virtual void cleanup_i (CORBA::Environment &ACE_TRY_ENV = TAO_default_environment ());
+ // Cleanup all resources used by this object.
- void on_disconnected (CORBA::Environment &ACE_TRY_ENV);
- // Derived classes should call this when their suppliers disconnect.
+ CORBA::Boolean check_filters_i (const TAO_Notify_Event& event, CORBA::Environment& ACE_TRY_ENV);
+ // Check filters.
- // = Data members
- TAO_Notify_SupplierAdmin_i* supplier_admin_;
- // My parent supplier admin.
+ void on_connected (CORBA::Environment &ACE_TRY_ENV);
+ // Derived classes should call this when their suppliers connect.
- TAO_Notify_Worker_Task* filter_eval_task_;
- // The filter evaluation task for this listener.
+ // = Data members
+ TAO_Notify_SupplierAdmin_i* myadmin_;
+ // My parent supplier admin.
};
#if defined (ACE_TEMPLATES_REQUIRE_SOURCE)